@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
 # SPDX-License-Identifier: ISC
 # Copyright (c) Justus Winter <4winter@informatik.uni-hamburg.de>
 
-from __future__ import print_function, absolute_import, unicode_literals
-
-from .BaseFilter import Filter
+from afew.filters.BaseFilter import Filter
 
 
 class KillThreadsFilter(Filter):
